# BELA

**B**LIP  **E**LAN  **L**anguage **A**nnotation - A Python package for processing ELAN-based multi-lingual transcriptions.

- Documentation: [https://github.com/letuananh/bela-convention](https://github.com/letuananh/bela-convention)
- Source code: [https://github.com/letuananh/bela](https://github.com/letuananh/bela)
- PyPI: [https://pypi.org/project/bela/](https://pypi.org/project/bela/)


This package will be released to the general public by 01 Mar 2021.
